.. _vmware_ansible:

******************
Ansible for VMware
******************

Welcome to the Ansible for VMware Guide! This is a set of placeholder docs to be filled in.

The purpose of this guide is to teach you everything you need to know about using Ansible with VMware.

To get started, please select one of the following topics.


.. toctree::
   :maxdepth: 2

   vmware_intro
   vmware_concepts
   vmware_requirements
   vmware_getting_started
   vmware_scenarios
   vmware_module_reference
   vmware_troubleshooting
   vmware_external_doc_links
   faq
